@@ -2,14 +2,14 @@
 from enum import Enum
 
 from pydantic import (  # pylint: disable=no-name-in-module
-    Field,
     AnyUrl,
     root_validator,
 )
 from typing import Union, Optional
 
-from .jsonapi import Link, Attributes
-from .entries import EntryResource
+from optimade.models.jsonapi import Link, Attributes
+from optimade.models.entries import EntryResource
+from optimade.models.utils import StrictField
 
 
 __all__ = (
@@ -39,31 +39,31 @@ class Aggregate(Enum):
 class LinksResourceAttributes(Attributes):
     """Links endpoint resource object attributes"""
 
-    name: str = Field(
+    name: str = StrictField(
         ...,
         description="Human-readable name for the OPTIMADE API implementation, e.g., for use in clients to show the name to the end-user.",
     )
-    description: str = Field(
+    description: str = StrictField(
         ...,
         description="Human-readable description for the OPTIMADE API implementation, e.g., for use in clients to show a description to the end-user.",
     )
-    base_url: Union[AnyUrl, Link, None] = Field(
+    base_url: Optional[Union[AnyUrl, Link]] = StrictField(
         ...,
         description="JSON API links object, pointing to the base URL for this implementation",
     )
 
-    homepage: Union[AnyUrl, Link, None] = Field(
+    homepage: Optional[Union[AnyUrl, Link]] = StrictField(
         ...,
         description="JSON API links object, pointing to a homepage URL for this implementation",
     )
 
-    link_type: LinkType = Field(
+    link_type: LinkType = StrictField(
         ...,
         description="""The type of the linked relation.
 MUST be one of these values: 'child', 'root', 'external', 'providers'.""",
     )
 
-    aggregate: Optional[Aggregate] = Field(
+    aggregate: Optional[Aggregate] = StrictField(
         "ok",
         description="""A string indicating whether a client that is following links to aggregate results from different OPTIMADE implementations should follow this link or not.
 This flag SHOULD NOT be indicated for links where `link_type` is not `child`.
@@ -77,7 +77,7 @@ A client MAY follow the link anyway if it has reason to do so (e.g., if the clie
 If specified, it MUST be one of the values listed in section Link Aggregate Options.""",
     )
 
-    no_aggregate_reason: Optional[str] = Field(
+    no_aggregate_reason: Optional[str] = StrictField(
         None,
         description="""An OPTIONAL human-readable string indicating the reason for suggesting not to aggregate results following the link.
 It SHOULD NOT be present if `aggregate`=`ok`.""",
@@ -87,13 +87,14 @@ It SHOULD NOT be present if `aggregate`=`ok`.""",
 class LinksResource(EntryResource):
     """A Links endpoint resource object"""
 
-    type: str = Field(
+    type: str = StrictField(
         "links",
-        const=True,
+        const="links",
         description="These objects are described in detail in the section Links Endpoint",
+        pattern="^links$",
     )
 
-    attributes: LinksResourceAttributes = Field(
+    attributes: LinksResourceAttributes = StrictField(
         ...,
         description="A dictionary containing key-value pairs representing the Links resource's properties.",
     )
